Learn R Programming

uniswappeR (version 0.6.1)

swaps: Get all the swaps data for a given address or addresses

Description

Get all the swaps data for a given address or addresses

Usage

swaps(address)

Value

dataframe on the swaps for the given account owner

Arguments

address

A wallet address (or vector of addresses) for the account owner's account

Examples

Run this code

addresses <- c("0xb1b117a45aD71d408eb55475FC3A65454edCc94A",
"0x41D2a18E1DdACdAbFDdADB62e9AEE67c63070b76",
"0x0De20c4bDBE0d0EEFFd2956Be4c148CA86C6cC45")

swaps(addresses)

Run the code above in your browser using DataLab