trade_eth.to.tok_tok.fix: Swap ETH for a Token, Buy specified fixed Token Amount
Description
Swap ETH for a Token, Buy specified fixed Token Amount
Usage
trade_eth.to.tok_tok.fix(t_a, t_d, t_q, u_w)
Value
Character vector representing the Transaction Hash
Arguments
- t_a
Token Address
- t_d
Token Decimals
- t_q
Token Qty.
- u_w
Uniswap Session