check_eth.to.tok_eth.fix: Swap ETH for a Token, Given ETH Qty check how much token you would get
Description
Swap ETH for a Token, Given ETH Qty check how much token you would get
Usage
check_eth.to.tok_eth.fix(t_a, t_d, e_q, u_w)
Value
Numeric vector representing the Token Amount you get
Arguments
- t_a
Token Address
- t_d
Token Decimals
- e_q
Ethereum Qty.
- u_w
Uniswap Session